/*
 *  Copyright 2012 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

Ext.namespace('org.ametys.newsletter.ribbon');

/**
 * Create the control instance.
 * @param {String} id The unique identifier
 * @param {Map<id, value>} configuration The configuration of the control instance.
 * @param {String} pluginName The name of the declaring plugin
 * @class This class implements the behavior for an action.
 * @extends org.ametys.ribbon.control.RibbonControl
 */
org.ametys.newsletter.ribbon.AutomaticNewsletterActionButton = function(id, configuration, pluginName)
{
    org.ametys.newsletter.ribbon.AutomaticNewsletterActionButton.superclass.constructor.call(this, id, configuration, pluginName);
}

Ext.extend(org.ametys.newsletter.ribbon.AutomaticNewsletterActionButton, org.ametys.newsletter.ribbon.CategoryWithTemplateActionButton, {});

/**
 * Creates the toggle button
 * @param {integer} colspan The configured colspan. Must be transmited to the control.
 * @return {Ext.form.field} The toggle button created. 
 */
org.ametys.newsletter.ribbon.AutomaticNewsletterActionButton.prototype.onMessage = function(messages)
{
    for (var i=0; i < messages.length; i++)
    {
        if (messages[i].getType().getName() == org.ametys.ribbon.RibbonManager.EVENTTYPE_SELECTIONCHANGED
            || messages[i].getType().getName() == org.ametys.ribbon.RibbonManager.EVENTTYPE_METADATACHANGED)
        {
            var targets = messages[i].getTargets();
            var target = org.ametys.messagebus.message.MessageTargetHelper.findFirst(targets, this._checkTarget.createDelegate(this));
            
            if (target != null && this._checkMode (target))
            {
                if (target.getParameters().template != '')
                {
                    var params = {categoryIds: [target.getParameters().id]};
                    
                    // Set the toggled state.
                    org.ametys.ribbon.RibbonManager.getInstance().refreshElement('control', this, params);
                }
                else
                {
                    this.getElements().each(function(element) { element.disable(); element.toggle(false); })
                    this.updateTooltip(this.getConfiguration()["no-template-description"], null, null);
                }
                
                this._currentCategory = target.getParameters().id;
                return;
            }
            else
            {
                this._currentCategory = null;
                this.getElements().each(function(element) { element.disable(); element.toggle(false); })
                this.updateTooltip(this.getConfiguration()["disabled-description"], null, null);
            }
        }
        else if (messages[i].getType().getName() == 'templateChanged')
        {
            var targets = messages[i].getTargets();
            var target = org.ametys.messagebus.message.MessageTargetHelper.findFirst(targets, this._checkTarget.createDelegate(this));
            
            if (target != null && target.getParameters().id == this._currentCategory)
            {
                if (target.getParameters().template != '')
                {
                    var params = {categoryIds: [target.getParameters().id]};
                    
                    // Set the toggled state.
                    org.ametys.ribbon.RibbonManager.getInstance().refreshElement('control', this, params);
                }
                else
                {
                    this.getElements().each(function(element) { element.disable(); element.toggle(false); })
                    this.updateTooltip(this.getConfiguration()["no-template-description"], null, null);
                }
            }
        }
    }
}

org.ametys.newsletter.ribbon.AutomaticNewsletterActionButton.prototype.configurationError = function(response)
{
    this.getElements().each(function(element) { element.stopRefreshing(); element.setDisabled(true); });
    this.updateTooltip(this.getConfiguration()['default-description']);
}

org.ametys.newsletter.ribbon.AutomaticNewsletterActionButton.prototype.configurationChanged = function(params)
{
    this.getElements().each(function(element) { element.stopRefreshing(); });
    
    var availableAutoNewsletterCount = parseInt(params['available-auto-newsletter-count']);
    var autoNewsletterCount = parseInt(params['auto-newsletter-count']);
    
    var disabledState = availableAutoNewsletterCount < 1;
    var toggledState = autoNewsletterCount > 0;
    
    var tooltip = this._getTooltip(params, availableAutoNewsletterCount, autoNewsletterCount);
    
    this.updateTooltip(tooltip, null, null);
    
    this.getElements().each(function(element) {
        element.setDisabled(disabledState);
        element.toggle(toggledState, true);
    });
}

org.ametys.newsletter.ribbon.AutomaticNewsletterActionButton.prototype._getTooltip = function(params, availableAutoNewsletterCount, autoNewsletterCount)
{
    var tooltip = this.getConfiguration()['default-description'];
    
    if (availableAutoNewsletterCount < 1)
    {
        tooltip = this.getConfiguration()['no-auto-description'];
    }
    else if (autoNewsletterCount > 0)
    {
        tooltip = tooltip + '<br/><br/>' + this.getConfiguration()['toggled-description'];
    }
    
    return tooltip;
}
